nxp-pac

Crates

git

Versions

lpc55s69_cm33_core1

Flavors

Event

Struct Event 

#[repr(transparent)]
pub struct Event(pub u32);
event register

Tuple Fields

0: u32

Implementations

Source

impl Event

pub const fn rst(&self) -> bool

When bit is set, the controller and flash are reset.

pub const fn set_rst(&mut self, val: bool)

When bit is set, the controller and flash are reset.

pub const fn wakeup(&self) -> bool

When bit is set, the controller wakes up from whatever low power or powerdown mode was active.

pub const fn set_wakeup(&mut self, val: bool)

When bit is set, the controller wakes up from whatever low power or powerdown mode was active.

pub const fn abort(&self) -> bool

When bit is set, a running program/erase command is aborted.

pub const fn set_abort(&mut self, val: bool)

When bit is set, a running program/erase command is aborted.