#[repr(transparent)]pub struct IntEnable(pub u32);Expand description
Interrupt enable bits
Tuple Fields
0: u32Implementations
Sourceimpl IntEnable
impl IntEnable
Sourcepub const fn fail(&self) -> bool
pub const fn fail(&self) -> bool
If an INT_ENABLE bit is set, an interrupt request will be generated if the corresponding INT_STATUS bit is high.
Sourcepub const fn set_fail(&mut self, val: bool)
pub const fn set_fail(&mut self, val: bool)
If an INT_ENABLE bit is set, an interrupt request will be generated if the corresponding INT_STATUS bit is high.
Sourcepub const fn err(&self) -> bool
pub const fn err(&self) -> bool
If an INT_ENABLE bit is set, an interrupt request will be generated if the corresponding INT_STATUS bit is high.
Sourcepub const fn set_err(&mut self, val: bool)
pub const fn set_err(&mut self, val: bool)
If an INT_ENABLE bit is set, an interrupt request will be generated if the corresponding INT_STATUS bit is high.
Sourcepub const fn done(&self) -> bool
pub const fn done(&self) -> bool
If an INT_ENABLE bit is set, an interrupt request will be generated if the corresponding INT_STATUS bit is high.
Sourcepub const fn set_done(&mut self, val: bool)
pub const fn set_done(&mut self, val: bool)
If an INT_ENABLE bit is set, an interrupt request will be generated if the corresponding INT_STATUS bit is high.
Sourcepub const fn ecc_err(&self) -> bool
pub const fn ecc_err(&self) -> bool
If an INT_ENABLE bit is set, an interrupt request will be generated if the corresponding INT_STATUS bit is high.
Sourcepub const fn set_ecc_err(&mut self, val: bool)
pub const fn set_ecc_err(&mut self, val: bool)
If an INT_ENABLE bit is set, an interrupt request will be generated if the corresponding INT_STATUS bit is high.