nxp-pac

Crates

git

Versions

lpc55s69_cm33_core1

Flavors

Starta

Struct Starta 

#[repr(transparent)]
pub struct Starta(pub u32);
start (or only) address for next flash command

Tuple Fields

0: u32

Implementations

Source

impl Starta

pub const fn starta(&self) -> u32

Address / Start address for commands that take an address (range) as a parameter.

pub const fn set_starta(&mut self, val: u32)

Address / Start address for commands that take an address (range) as a parameter.