nxp-pac

Crates

git

Versions

lpc55s69_cm33_core1

Flavors

Stopa

Struct Stopa 

#[repr(transparent)]
pub struct Stopa(pub u32);
end address for next flash command, if command operates on address ranges

Tuple Fields

0: u32

Implementations

Source

impl Stopa

pub const fn stopa(&self) -> u32

Stop address for commands that take an address range as a parameter (the word specified by STOPA is included in the address range).

pub const fn set_stopa(&mut self, val: u32)

Stop address for commands that take an address range as a parameter (the word specified by STOPA is included in the address range).