#[repr(transparent)]pub struct Event(pub u32);Expand description
event register
Tuple Fields
0: u32Implementations
Sourceimpl Event
impl Event
Sourcepub const fn set_rst(&mut self, val: bool)
pub const fn set_rst(&mut self, val: bool)
When bit is set, the controller and flash are reset.
Sourcepub const fn wakeup(&self) -> bool
pub const fn wakeup(&self) -> bool
When bit is set, the controller wakes up from whatever low power or powerdown mode was active.
Sourcepub const fn set_wakeup(&mut self, val: bool)
pub const fn set_wakeup(&mut self, val: bool)
When bit is set, the controller wakes up from whatever low power or powerdown mode was active.